using System.Collections.ObjectModel;
using System;
using System.ComponentModel;

public class ViewModel : INotifyPropertyChanged
    {
        public ObservableCollection<GridData> Data {get;set;}
        public ObservableCollection<RecDescription> RecDescs { get; set; }
       


        private GridData _activeItem;
        public GridData ActiveItem
        {
            get { return _activeItem; }
            set
            {
                if (_activeItem != value)
                {
                    _activeItem = value;
                    OnPropertyChanged("ActiveItem");
                }
            }
        }


       

        public ViewModel()
        {
            CreateData();
            
        }

        private string[] names = { "John", "Kim", "Sandy", "Mark", "Josh", "Jim", "Sam", "Mary", 
                                     "Harry", "Sue", "Chris", "Joe", "Carl" };
        private string[] recDescs = { "Duplicate", "Expired", "History","New", "Safe","Standard", "Test", "Trial"  };
        private void CreateData()
        {
            Random r = new Random();
            Data = new ObservableCollection<GridData>();
            for (int i = 0; i < 100; i++)
            {
                int num = r.Next(7);
                Data.Add(new GridData()
                {
                    ID = i,
                    Name = names[r.Next(13)],
                    RecDesc = num,
                    DescReason = num * 10 + r.Next(5),
                    RecDate = DateTime.Today.AddDays(r.Next(10))
                });
            }

            RecDescs = new ObservableCollection<RecDescription>();
            for (int i = 0; i < 7; i++)
            {
                RecDescs.Add(new RecDescription() {ID=i,Description = recDescs[i]});
            }

            
        }


        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

    }
    public class GridData : INotifyPropertyChanged
    {
        
        private int id;
        private string name;
        private DateTime recDt;
        private int rec_desc;
        private int desc_reason;


        public int ID
        {
            get { return id; }
            set
            {
                if (id != value)
                {
                    id = value;
                    OnPropertyChanged("ID");
                }
            }
        }

        public string Name
        {
            get { return name; }
            set
            {
                if (name != value)
                {
                    name = value;
                    OnPropertyChanged("Name");
                }
            }
        }

        public int RecDesc
        {
            get { return rec_desc; }
            set
            {
                if (rec_desc != value)
                {
                    rec_desc = value;
                    OnPropertyChanged("RecDesc");
                }
            }
        }
        public int DescReason
        {
            get { return desc_reason; }
            set
            {
                if (desc_reason != value)
                {
                    desc_reason = value;
                    OnPropertyChanged("DescReason");
                }
            }
        }

        public DateTime RecDate
        {
            get { return recDt; }
            set
            {
                if (recDt != value)
                {
                    recDt = value;
                    OnPropertyChanged("RecDate");
                }
            }
        }



        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
public class RecDescription
{
    public int ID { get; set; }
    public string Description { get; set; }
}
public class DescriptionReason
{
    public int ID { get; set; }
    public int DescID { get; set; }
    public string Description { get; set; }
}

public static class DescriptionReasons
{
    private static string[] recDescs = { "Duplicate", "Expired", "History", "New", "Safe", "Standard", "Test", "Trial" };
    public static ObservableCollection<DescriptionReason> Reasons
    {
        get;
        set;
    }

    static DescriptionReasons()
    {
        
        Reasons = new ObservableCollection<DescriptionReason>();
        for (int i = 0; i < 7; i++)
        {
            for (int j = 0; j < 5; j++)
            {
                Reasons.Add(new DescriptionReason()
                {
                    ID = i * 10 + j,
                    DescID = i,
                    Description = recDescs[i] + " Reason " + j

                });
            }
        }
           

    }
}

